# Python bindings

The Glean SDK contains Python bindings for use in Python applications and test frameworks.
It makes use of the underlying [Rust component](../core/index.md) with a Python-specific API on top.
